@@ -17,12 +17,12 @@ def Service (uri, service_key, gpg_homedir = None, gpg_key = None, gpg_password
     if ticket:
         headers.update ({'RCO-Ticket': ticket})
     return pgpxmlrpc.Service (
-        uri,
-        service_key,
-        gpg_homedir or base.config ('security.homedir', strict = True),
-        gpg_key or base.config ('security.key', strict = True),
-        gpg_password or base.config ('security.password', strict = True),
-        headers
+        uri = uri,
+        service_key = service_key,
+        gpg_homedir = gpg_homedir or base.config ('security.homedir', strict = True),
+        gpg_key = gpg_key or base.config ('security.key', strict = True),
+        gpg_password = gpg_password or base.config ('security.password', strict = True),
+        headers = headers
     )
 
 
